@@ -1,7 +1,6 @@
 import { ReducersMapObject } from '@reduxjs/toolkit';
 import { AnyAction, combineReducers } from 'redux';
 
-import { notificationsAPIv0alpha1, rulesAPIv0alpha1 } from '@grafana/alerting/unstable';
 import { allReducers as allApiClientReducers } from '@grafana/api-clients/rtkq';
 import { generatedAPI as legacyAPI } from '@grafana/api-clients/rtkq/legacy';
 import sharedReducers from 'app/core/reducers';
@@ -23,7 +22,6 @@ import { reducer as pluginsReducer } from 'app/features/plugins/admin/state/redu
 import userReducers from 'app/features/profile/state/reducers';
 import serviceAccountsReducer from 'app/features/serviceaccounts/state/reducers';
 import supportBundlesReducer from 'app/features/support-bundles/state/reducers';
-import teamsReducers from 'app/features/teams/state/reducers';
 import usersReducers from 'app/features/users/state/reducers';
 import templatingReducers from 'app/features/variables/state/keyedVariablesReducer';
 
@@ -33,7 +31,6 @@ import { cleanUpAction } from '../actions/cleanUp';
 const rootReducers = {
   ...sharedReducers,
   ...alertingReducers,
-  ...teamsReducers,
   ...dashboardReducers,
   ...exploreReducers,
   ...dataSourcesReducers,
@@ -53,8 +50,6 @@ const rootReducers = {
   [legacyAPI.reducerPath]: legacyAPI.reducer,
   plugins: pluginsReducer,
   [alertingApi.reducerPath]: alertingApi.reducer,
-  [notificationsAPIv0alpha1.reducerPath]: notificationsAPIv0alpha1.reducer,
-  [rulesAPIv0alpha1.reducerPath]: rulesAPIv0alpha1.reducer,
   [publicDashboardApi.reducerPath]: publicDashboardApi.reducer,
   [browseDashboardsAPI.reducerPath]: browseDashboardsAPI.reducer,
   ...allApiClientReducers,
