@@ -1,18 +1,19 @@
-import { AbstractLabelOperator, DataFrame, TimeRange, dateTime, getDefaultTimeRange, ScopedVars } from '@grafana/data';
+import { AbstractLabelOperator, DataFrame, TimeRange, dateTime, ScopedVars } from '@grafana/data';
 import { config } from '@grafana/runtime';
 
 import LanguageProvider from './LanguageProvider';
-import { createDetectedFieldValuesMetadataRequest } from './__mocks__/createDetectedFieldValuesMetadataRequest';
-import { createDetectedFieldsMetadataRequest } from './__mocks__/createDetectedFieldsMetadataRequest';
-import { createLokiDatasource } from './__mocks__/datasource';
-import { createMetadataRequest } from './__mocks__/metadataRequest';
+import { LokiQueryType } from './dataquery.gen';
 import { DEFAULT_MAX_LINES_SAMPLE, LokiDatasource } from './datasource';
+import { createDetectedFieldValuesMetadataRequest } from './mocks/createDetectedFieldValuesMetadataRequest';
+import { createDetectedFieldsMetadataRequest } from './mocks/createDetectedFieldsMetadataRequest';
+import { createLokiDatasource } from './mocks/datasource';
+import { createMetadataRequest } from './mocks/metadataRequest';
 import {
   extractLogParserFromDataFrame,
   extractLabelKeysFromDataFrame,
   extractUnwrapLabelKeysFromDataFrame,
 } from './responseUtils';
-import { DetectedFieldsResult, LabelType, LokiQueryType } from './types';
+import { DetectedFieldsResult, LabelType } from './types';
 
 jest.mock('./responseUtils');
 
@@ -25,18 +26,6 @@ const mockTimeRange = {
   },
 };
 
-jest.mock('@grafana/data', () => ({
-  ...jest.requireActual('@grafana/data'),
-  getDefaultTimeRange: jest.fn().mockImplementation(() => ({
-    from: dateTime(0),
-    to: dateTime(1),
-    raw: {
-      from: dateTime(0),
-      to: dateTime(1),
-    },
-  })),
-}));
-
 describe('Language completion provider', () => {
   describe('start', () => {
     const datasource = setup({ testkey: ['label1_val1', 'label1_val2'], label2: [] });
@@ -208,8 +197,16 @@ describe('Language completion provider', () => {
         .mockImplementation((range: TimeRange) => ({ start: range.from.valueOf(), end: range.to.valueOf() }));
       const languageProvider = new LanguageProvider(datasource);
       languageProvider.request = jest.fn().mockResolvedValue([]);
+      jest.spyOn(languageProvider, 'getDefaultTimeRange').mockImplementation(() => ({
+        from: dateTime(0),
+        to: dateTime(1),
+        raw: {
+          from: dateTime(0),
+          to: dateTime(1),
+        },
+      }));
       languageProvider.fetchLabelValues('testKey');
-      expect(getDefaultTimeRange).toHaveBeenCalled();
+      expect(languageProvider.getDefaultTimeRange).toHaveBeenCalled();
       expect(languageProvider.request).toHaveBeenCalled();
       expect(languageProvider.request).toHaveBeenCalledWith('label/testKey/values', {
         end: 1,
@@ -563,6 +560,23 @@ describe('Language completion provider', () => {
           start: 1560153109000,
         });
       });
+
+      it('should interpolate variables in stream selector', async () => {
+        const datasource = setup({});
+        jest.spyOn(datasource, 'getTimeRangeParams').mockReturnValue({ start: 0, end: 1 });
+        jest
+          .spyOn(datasource, 'interpolateString')
+          .mockImplementation((string: string) => string.replace(/\$test_var/g, 'age'));
+
+        const languageProvider = new LanguageProvider(datasource);
+        languageProvider.request = jest.fn().mockResolvedValue([]);
+        await languageProvider.fetchLabels({ streamSelector: '{age="new", $test_var="new"}' });
+        expect(languageProvider.request).toHaveBeenCalledWith('labels', {
+          end: 1,
+          query: '{age="new", age="new"}',
+          start: 0,
+        });
+      });
     });
 
     it('should filter internal labels', async () => {
@@ -681,14 +695,6 @@ describe('Query imports', () => {
   });
 
   describe('getParserAndLabelKeys()', () => {
-    const queryHintsFeatureToggle = config.featureToggles.lokiQueryHints;
-    beforeAll(() => {
-      config.featureToggles.lokiQueryHints = true;
-    });
-    afterAll(() => {
-      config.featureToggles.lokiQueryHints = queryHintsFeatureToggle;
-    });
-
     let datasource: LokiDatasource, languageProvider: LanguageProvider;
     const extractLogParserFromDataFrameMock = jest.mocked(extractLogParserFromDataFrame);
     const extractedLabelKeys = ['extracted', 'label'];
@@ -773,7 +779,8 @@ describe('Query imports', () => {
           maxLines: DEFAULT_MAX_LINES_SAMPLE,
           refId: 'data-samples',
         },
-        getDefaultTimeRange()
+        // We are not interested in the time range here
+        expect.any(Object)
       );
     });
 
@@ -794,7 +801,8 @@ describe('Query imports', () => {
           maxLines: 5,
           refId: 'data-samples',
         },
-        getDefaultTimeRange()
+        // We are not interested in the time range here
+        expect.any(Object)
       );
     });
 
@@ -810,12 +818,6 @@ describe('Query imports', () => {
         mockTimeRange
       );
     });
-    it('does not call dataSample with feature toggle disabled', async () => {
-      config.featureToggles.lokiQueryHints = false;
-      jest.spyOn(datasource, 'getDataSamples');
-      languageProvider.getParserAndLabelKeys('{place="luna"}', { timeRange: mockTimeRange });
-      expect(datasource.getDataSamples).not.toHaveBeenCalled();
-    });
   });
 });
 
